==> haskell-tuple-0.3.0.2-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-8DLMJydfKjb3VR6hDx0dFI
key:                  tuple-0.3.0.2-8DLMJydfKjb3VR6hDx0dFI
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  c57b0403585c861514e059391a089fe8
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-8DLMJydfKjb3VR6hDx0dFI
depends:              OneTuple-0.4.2-F2KfgqKvaSO28upnL0ond3 base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tuple-0.3.0.2-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-7uYWNzKABpuARShOJ0OjHW
key:                  tuple-0.3.0.2-7uYWNzKABpuARShOJ0OjHW
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  af69b1f8a4745b8fb80814cf33ff3d27
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-7uYWNzKABpuARShOJ0OjHW
depends:              OneTuple-0.4.2-3CeSkaxtMkG9rfkZdvylk0 base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
